@@ -19,6 +19,13 @@ CLI_CONFIG = {
         "action": "store_true",
         "help": "Display version information",
     },
+    "config_template": {
+        "dyne": "__cli__",
+        "subcommands": ["_global_"],
+        "default": False,
+        "action": "store_true",
+        "help": "Output a config template for this command",
+    },
 }
 
 CONFIG = {
@@ -31,7 +38,7 @@ CONFIG = {
     "log_level": {
         "dyne": "__cli__",
         "default": "warning",
-        "help": "Set the log level, either quiet, info, warning, or error",
+        "help": "Set the log level, either quiet, info, warning, debug or error",
         "group": "Logging Options",
     },
     "log_fmt_logfile": {
